@@ -8,24 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_kinesis._jsii
-import aws_cdk.aws_kinesisanalytics._jsii
-import aws_cdk.aws_kinesisfirehose._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.aws_kinesis_firehose_s3._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-kinesisfirehose-s3-and-kinesisanalytics",
-    "1.181.0",
+    "2.9.0",
     __name__[0:-6],
-    "aws-kinesisfirehose-s3-and-kinesisanalytics@1.181.0.jsii.tgz",
+    "aws-kinesisfirehose-s3-and-kinesisanalytics@2.9.0.jsii.tgz",
 )
 
 __all__ = [
